
set.seed(1234)

library(readxl)
dat1 <- read_excel("MCT_Studie_final_230201.xlsx", sheet = "G C8 C10")

dat1$Behandlung<-factor(dat1$Behandlung, levels = c("Pla","MCT","MCt + Glu"),
                                         labels = c("CONTROL","MCT","MCT+Glc"))

### exclude ID16
dat1<-dat1[dat1$ID!=16,]

### n/Treatment
table(dat1$Behandlung)


BHB <- read_excel("MCT_Studie_final_230201.xlsx", sheet = "BHB")
BHB1<-t(BHB[,-1:-3])
BHB1<-as.data.frame(BHB1)


Glucose <- read_excel("MCT_Studie_final_230201.xlsx", sheet = "Glucose ")
Glucose1<-t(Glucose[,-1:-3])
Glucose1<-as.data.frame(Glucose1)

Insulin <- read_excel("MCT_Studie_final_230201.xlsx", sheet = "Insulin")
Insulin1<-t(Insulin[,-1:-3])
Insulin1<-as.data.frame(Insulin1)

Scores <- read_excel("MCT_Studie_final_230201.xlsx", sheet = "Intelligenz_long")
Scores$Behandlung<-factor(Scores$Behandlung, levels = 1:3,labels = c("CONTROL","MCT","MCT+Glc"))

############################################

source("Reshape_230204.R")

############################################

AUC<- function(y0,y1,y2,y3,y4,y5,y6,y7) {
  (y1+y0)/2*30+
  (y2+y1)/2*30+
  (y3+y2)/2*30+
  (y4+y3)/2*30+
  (y5+y4)/2*60+
  (y6+y5)/2*60+
  (y7+y6)/2*60
  }

dat1$C8_AUC<-with(dat1,AUC(C8_0,C8_30,C8_60,C8_90,C8_120,C8_180,C8_240,C8_300))
dat1$C8_sum<-apply(dat1[,14:21],1, sum)
dat1$C8_mean<-apply(dat1[,14:21],1, mean)
      

dat1$C10_AUC<-with(dat1,AUC(C10_0,C10_30,C10_60,C10_90,C10_120,C10_180,C10_240,C10_300))
dat1$C10_sum<-apply(dat1[,22:29],1, sum)
dat1$C10_mean<-apply(dat1[,22:29],1, mean)

dat1<-dat1[order(dat1$Behandlung),]
dat1<-dat1[,c(1:5,30:35)]
# View(dat1)

## BHB
Placebo<-with(BHB1,AUC(V1,V2,V3,V4,V5,V6,V7,V8))
MCT<-with(BHB1,AUC(V9,V10,V11,V12,V13,V14,V15,V16))
MCTGlu<-with(BHB1,AUC(V17,V18,V19,V20,V21,V22,V23,V24))
BHB<-c(Placebo,MCT,MCTGlu)                    
## View(BHB)
dat1$BHB_AUC<-BHB
BHB_AUC<-cbind(Placebo,MCT,MCTGlu)


## Glucose
Placebo<-with(Glucose1,AUC(V1,V2,V3,V4,V5,V6,V7,V8))
MCT<-with(Glucose1,AUC(V9,V10,V11,V12,V13,V14,V15,V16))
MCTGlu<-with(Glucose1,AUC(V17,V18,V19,V20,V21,V22,V23,V24))
Glucose<-c(Placebo,MCT,MCTGlu)                    
# View(Glucose)
dat1$Glucose_AUC<-Glucose
Glucose_AUC<-cbind(Placebo,MCT,MCTGlu)

## Insulin
Placebo<-with(Insulin1,AUC(V1,V2,V3,V4,V5,V6,V7,V8))
MCT<-with(Insulin1,AUC(V9,V10,V11,V12,V13,V14,V15,V16))
MCTGlu<-with(Insulin1,AUC(V17,V18,V19,V20,V21,V22,V23,V24))
Insulin<-c(Placebo,MCT,MCTGlu)                    
#View(Insulin)
dat1$Insulin_AUC<-Insulin
Insulin_AUC<-cbind(Placebo,MCT,MCTGlu)

# View(dat1)

require(Hmisc)
label(dat1, self = F)<-c("ID","Date","Treatment","Dose","Body weight",
                         "AUC (C8)","Sum (C8)","Mean (C8)",
                         "AUC (C10)","Sum (C10)","Mean (C10)",
                         "AUC (BHB)","AUC (Glucose)","AUC (Insulin)")


#### Data restructuring

dat2<-dat1[dat1$Behandlung!="CONTROL",]
dat2$Behandlung<-droplevels(dat2$Behandlung)

MCt<-dat2[dat2$Behandlung=="MCT",]
MCtGlu<-dat2[dat2$Behandlung=="MCT+Glc",]

diff_AUC_C8<-MCt$C8_AUC-MCtGlu$C8_AUC
diff_AUC_C10<-MCt$C10_AUC-MCtGlu$C10_AUC


### AUC C8 und C10

library(ggplot2)
library(ggpubr)
library(gridExtra)

my_comparisons <- list(c("MCT","MCT+Glc"))

C8AUC_1<-ggplot(data=dat2,aes(x=Behandlung, y=C8_AUC, fill=Behandlung)) +
    stat_boxplot(geom = "errorbar", width = 0.15) +   
    geom_boxplot(outlier.shape=NA, outlier.colour = 2, 
    # fill = c("cornsilk3","cadetblue")) +    
    fill=c("#ED7D31","#C00000")) +
    # geom_boxplot(outlier.shape=NA) 
    ylab("AUC C8") +
    #scale_fill_viridis(discrete = TRUE, alpha=0.6) +
    geom_jitter(color="black", size=1.5, alpha=0.9, width = .2) +
    theme(
      axis.text=element_text(size=18),
      axis.title.y = element_text(size = rel(1.5)),
      legend.position="none",
      plot.title = element_text(size=18, face="bold",hjust = 0.5)) +
    ggtitle("(A)") +
    xlab("") +
    stat_compare_means(comparisons = my_comparisons,size=5,paired = T)


C10AUC_1<-ggplot(data=dat2,aes(x=Behandlung, y=C10_AUC, fill=Behandlung)) +
    stat_boxplot(geom = "errorbar", width = 0.15) +   
    geom_boxplot(fill=c("#ED7D31","#C00000"), outlier.shape=NA, outlier.colour = 2) + 
    ylab("AUC C10") +
    geom_jitter(color="black", size=1.5, alpha=0.9, width = .2) +
    theme(
      axis.text=element_text(size=18),
      axis.title.y = element_text(size = rel(1.5)),
      legend.position="none",
      plot.title = element_text(size=18, face="bold",hjust = 0.5)) +
    ggtitle("(B)") +
    xlab("")+
    stat_compare_means(comparisons = my_comparisons,size=5,paired = T) 

grid.arrange(C8AUC_1, C10AUC_1, ncol=2)

  
C8AUC_2<-ggplot(data=dat2,aes(x=Behandlung, y=C8_AUC, fill=Behandlung)) +
    stat_boxplot(geom = "errorbar", width = 0.15) +   
    geom_boxplot(fill=c("#ED7D31","#C00000")) + 
    ylab("AUC C8") +
    theme(
      axis.text=element_text(size=18),
      axis.title.y = element_text(size = rel(1.5)),
      legend.position="none",
      plot.title = element_text(size=18, face="bold",hjust = 0.5)) +
    ggtitle("(A)") +
    xlab("") +
    stat_compare_means(comparisons = my_comparisons,size=5,paired = T) 

C10AUC_2<-ggplot(data=dat2,aes(x=Behandlung, y=C10_AUC, fill=Behandlung)) +
    stat_boxplot(geom = "errorbar", width = 0.15) +   
    geom_boxplot(fill=c("#ED7D31","#C00000")) + 
    ylab("AUC C10") +
    theme(
      axis.text=element_text(size=18),
      axis.title.y = element_text(size = rel(1.5)),
      legend.position="none",
      plot.title = element_text(size=18, face="bold",hjust = 0.5)) +
    ggtitle("(B)") +
    xlab("") +
    stat_compare_means(comparisons = my_comparisons,size=5,paired = T)


grid.arrange(C8AUC_2, C10AUC_2, ncol=2)



pdf("C8_C10_AUC_Boxplot_230202.pdf",width=10, height=5)
grid.arrange(C8AUC_1, C10AUC_1, ncol=2)
grid.arrange(C8AUC_2, C10AUC_2, ncol=2)
dev.off()




### Scores: Vocabulary & Arithmetic 


my_comparisons <- list(c("CONTROL","MCT"),c("CONTROL","MCT+Glc"))

Vocabulary_1<-ggplot(data=Scores,aes(x=Behandlung, y=Vocabulary, fill=Behandlung)) +
    stat_boxplot(geom = "errorbar", width = 0.15) +   
    geom_boxplot(fill=c("#646464", "#ED7D31","#C00000"), outlier.shape=NA, outlier.colour = 2) + 
    ylab("Scaled Scores (Vocabulary)") +
    geom_jitter(color="black", size=1.5, alpha=0.9, width = .2, height = .1) +
    theme(
      axis.text=element_text(size=18),
      axis.title.y = element_text(size = rel(1.5)),
      legend.position="none",
      plot.title = element_text(size=18, face="bold",hjust = 0.5)) +
    ggtitle("(A)") +
    xlab("") +
    stat_compare_means(comparisons = my_comparisons,size=5,paired=T)



Arithmetic_1<-ggplot(data=Scores,aes(x=Behandlung, y=Arithmetic, fill=Behandlung)) +
    stat_boxplot(geom = "errorbar", width = 0.15) +   
    geom_boxplot(fill=c("#646464", "#ED7D31","#C00000"), outlier.shape=NA, outlier.colour = 2) + 
    ylab("Scaled Scores (Arithmetic)") +
    geom_jitter(color="black", size=1.5, alpha=0.9, width = .2, height = .1) +
    theme(
      axis.text=element_text(size=18),
      axis.title.y = element_text(size = rel(1.5)),
      legend.position="none",
      plot.title = element_text(size=18, face="bold",hjust = 0.5)) +
    ggtitle("(B)") +
    xlab("") +
    stat_compare_means(comparisons = my_comparisons,size=5,paired=T)

grid.arrange(Vocabulary_1,Arithmetic_1, ncol=2)



Vocabulary_2<-ggplot(data=Scores,aes(x=Behandlung, y=Vocabulary, fill=Behandlung)) +
    stat_boxplot(geom = "errorbar", width = 0.15) +   
    geom_boxplot(fill=c("#646464","#ED7D31","#C00000")) + 
    ylab("Scaled Scores (Vocabulary)") +
    theme(
      axis.text=element_text(size=18),
      axis.title.y = element_text(size = rel(1.5)),
      legend.position="none",
      plot.title = element_text(size=18, face="bold",hjust = 0.5)) +
    ggtitle("(A)") +
    xlab("") +
    stat_compare_means(comparisons = my_comparisons,size=5,paired=T)

Arithmetic_2<-ggplot(data=Scores,aes(x=Behandlung, y=Arithmetic, fill=Behandlung)) +
    stat_boxplot(geom = "errorbar", width = 0.15) +   
    geom_boxplot(fill=c("#646464","#ED7D31","#C00000")) + 
    ylab("Scaled Scores (Arithmetic)") +
    theme(
      axis.text=element_text(size=18),
      axis.title.y = element_text(size = rel(1.5)),
      legend.position="none",
      plot.title = element_text(size=18, face="bold",hjust = 0.5)) +
    ggtitle("(B)") +
    xlab("") +
    stat_compare_means(comparisons = my_comparisons,size=5,paired=T)


grid.arrange(Vocabulary_2,Arithmetic_2, ncol=2)




pdf("Intelligenz_Boxplot_230202.pdf",width=10, height=5)
grid.arrange(Vocabulary_1,Arithmetic_1, ncol=2)
grid.arrange(Vocabulary_2,Arithmetic_2, ncol=2)
dev.off()



### AUC (BHB)


my_comparisons <- list(c("CONTROL","MCT"),c("CONTROL","MCT+Glc"),
                       c("MCT","MCT+Glc"))

BHBAUC<-ggplot(data=dat1,aes(x=Behandlung, y=BHB_AUC, fill=Behandlung)) +
    stat_boxplot(geom = "errorbar", width = 0.15) +   
    geom_boxplot(fill=c("#646464","#ED7D31","#C00000")) + 
    #outlier.shape=NA, outlier.colour = 2, 
    ylab("AUC(BHB)") +
    #geom_jitter(color="black", size=1.5, alpha=0.9, width = .2) +
    theme(
      axis.text=element_text(size=18),
      axis.title.y = element_text(size = rel(1.5)),
      legend.position="none",
      plot.title = element_text(size=18, face="bold",hjust = 0.5)) +
    ggtitle("") +
    xlab("") +
    stat_compare_means(comparisons = my_comparisons,size=4,paired=T)

BHBAUC

pdf("AUC_BHB_Boxplot_230203.pdf",width=6, height=5)
BHBAUC
dev.off()



### Correlation MCT


d<-dat2[dat2$Behandlung=="MCT",c(4:6,9,12:14)]
names(d)[1:2]<-c("MCT Dose","Body weight")

round(cor(d, use ="pairwise.complete.obs", method = "spearman"),3)

require(corrplot)

round(cor.mtest(d, conf.level = 0.95, method = "spearman")$p,3)
plot(d)


### Correlation  MCT+Glc


d<-dat2[dat2$Behandlung=="MCT+Glc",c(4:6,9,12:14)] # "MCt","MCt+Glu"
names(d)[1:2]<-c("G. Dose","Body weight")
round(cor(d, use ="pairwise.complete.obs", method = "spearman"),3)


require(corrplot)

round(cor.mtest(d, conf.level = 0.95, method = "spearman")$p,3)

plot(d)


## Correlation Plots

require(corrplot)

v<-c(4:6,9,12:14)

d_MCt<-dat2[dat2$Behandlung=="MCT",v] # "MCt","MCt+Glu"
r_MCt<-round(cor(d_MCt, use ="pairwise.complete.obs", method = "spearman"),3)


d_MCtGlu<-dat2[dat2$Behandlung=="MCT+Glc",v] # "MCt","MCt+Glu"
r_MCtGlu<-round(cor(d_MCtGlu, use ="pairwise.complete.obs", method = "spearman"),3)


rownames(r_MCt)<-label(dat2[,v])
colnames(r_MCt)<-label(dat2[,v])

rownames(r_MCt)[1]<-"MCT Dose"
colnames(r_MCt)[1]<-"MCT Dose"


rownames(r_MCtGlu)<-label(dat2[,v])
colnames(r_MCtGlu)<-label(dat2[,v])

rownames(r_MCtGlu)[1]<-"Glucose Dose"
colnames(r_MCtGlu)[1]<-"Glucose Dose"


  
  
# pdf("CorrPlots_all_230202.pdf",width=10, height=5)

par(mfrow=c(1,2))
corrplot(r_MCt,tl.cex = 1, title = "MCT", mar=c(0,0,3,0))#.8
corrplot(r_MCtGlu,tl.cex = 1, title = "MCT+Glc", mar=c(0,0,3,0))#.8
par(mfrow=c(1,1))


## sig. Correlation



par(mfrow=c(1,2))


testRes_MCt = cor.mtest(d_MCt, conf.level = 0.95, method = "spearman")
testRes_MCtGlu = cor.mtest(d_MCtGlu, conf.level = 0.95, method = "spearman")

round(testRes_MCt$p,3)


rownames(testRes_MCt$p)<-label(dat2[,v])
colnames(testRes_MCt$p)<-label(dat2[,v])

rownames(testRes_MCt$p)[1]<-"MCT Dose"
colnames(testRes_MCt$p)[1]<-"MCT Dose"


rownames(testRes_MCtGlu$p)<-label(dat2[,v])
colnames(testRes_MCtGlu$p)<-label(dat2[,v])

rownames(testRes_MCtGlu$p)[1]<-"Glucose Dose"
colnames(testRes_MCtGlu$p)[1]<-"Glucose Dose"


#  sig. Correlation:
corrplot(r_MCt,tl.cex = 1,title = "MCT", mar=c(0,0,3,0),
         p.mat = testRes_MCt$p,  insig = 'blank')  #, type ="lower")

corrplot(r_MCtGlu,tl.cex = 1,title = "MCT+Glc", mar=c(0,0,3,0),
         p.mat = testRes_MCtGlu$p,  insig = 'blank')  #, type ="lower")

par(mfrow=c(1,1))
dev.off()



### Regression: BHB, C8 and C10   

dat <- read.csv("MCT_Studie_final_long_230204.csv")
dat$Behandlung<-factor(dat$Behandlung)

dat$ID<-factor(dat$ID)
dat<-dat[dat$Behandlung!="CONTROL",]



library(ggplot2)
REG_C8<-ggplot(dat, aes(x = C8, y = BHB)) + 
  geom_point() +
  geom_smooth(method='lm', se = T) +
  facet_wrap(~Behandlung) +
  theme(legend.position="none",
        axis.text=element_text(size=18),
        axis.title.x = element_text(size = rel(1.5)),
        axis.title.y = element_text(size = rel(1.5)),
        strip.text.x = element_text(size = 15))

REG_C8

summary(lm(BHB~C8, data = dat[dat$Behandlung=="MCT",]))
summary(lm(BHB~C8, data = dat[dat$Behandlung=="MCT+Glc",]))


REG_C10<-ggplot(dat, aes(x = C10, y = BHB)) + 
  geom_point() +
  geom_smooth(method='lm', se = T) +
  facet_wrap(~Behandlung) +
    theme(legend.position="none",
        axis.text=element_text(size=18),
        axis.title.x = element_text(size = rel(1.5)),
        axis.title.y = element_text(size = rel(1.5)),
        strip.text.x = element_text(size = 15))
  
REG_C10

summary(lm(BHB~C10, data = dat[dat$Behandlung=="MCT",]))
summary(lm(BHB~C10, data = dat[dat$Behandlung=="MCT+Glc",]))


pdf("REG_Plots_230202.pdf",width=10, height=5)
REG_C8
REG_C10
dev.off()

